/**
 * PETALS: PETALS Services Platform Copyright (C) 2005 EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 * 
 * Initial developer(s): EBM WebSourcing
 */
package org.ow2.petals.ant.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.types.LogLevel;
import org.ow2.petals.ant.AbstractJBIAntTask;

/**
 * Ant task : jbi-start-service-assembly. This task starts a particular service
 * assembly in the JBI environment.
 * 
 * @author ddesjardins chamerling - eBMWebsourcing
 */
public class StartServiceAssemblyTask extends AbstractJBIAntTask {

    /**
     * Name of the JBI Service Assembly
     */
    private String name;

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.ant.AbstractJBIAntTask#doTask()
     */
    @Override
    public void doTask() throws Exception {
        if (this.name == null) {
            throw new BuildException("Missing attribute 'name'");
        }

        String xmlReport = this.getJMXClient().getDeploymentServiceClient().start(this.name);

        // TODO : use a common library to handle properly the SA deployment
        // reports
        if (xmlReport.contains("<task-result>FAILED</task-result>")) {
            log("Failed to start Service Assembly '" + this.name + "'\n" + xmlReport,
                    LogLevel.ERR.getLevel());
        } else {
            log("Service assembly '" + name + "' started");
        }
    }

    /**
     * Set the name parameter
     * 
     * @param name
     */
    public void setName(String name) {
        this.name = name;
    }
}
